@@ -22,6 +22,8 @@ tgpt_providers = [
     "groq",
     "perplexity",
     "novita",
+    "ai4chat",
+    "deepseek",
 ]
 
 gpt4free_providers = [
